from distutils.core import setup as set

set(name='sendqqmail',version='0.1',package_dir={"":"sendqqmail"},py_modules = ['sendqqmail'],author = 'py3141',author_email = '3386165598@qq.com',url = '',description = 'A send QQ mail package')
